@@ -834,3 +834,41 @@ class AtlasEventTypes(Enum):
     ONLINE_ARCHIVE_DATA_EXPIRATION_RESOLVED = 'Online Archive Data Expiration Resolved'
     LOG_FORWARDER_FAILURE = 'Log Forwarder Failure'
     CLUSTER_UNLINKED_FROM_VERCEL = 'Cluster Unlinked From Vercel'
+    INGESTION_PIPELINE_DESTROYED = 'Ingestion Pipeline Destroyed'
+    TENANT_ENDPOINT_INITIATING = 'Tenant Endpoint Initiating'
+    ATLAS_SCHEDULED_MAINTENANCE_DELAYED = 'Atlas Scheduled Maintenance Delayed'
+    ATLAS_SCHEDULED_MAINTENANCE_COMPLETED = 'Atlas Scheduled Maintenance Completed'
+    FEDERATED_DATABASE_CREATED = 'Federated Database Created'
+    FEDERATED_DATABASE_UPDATED = 'Federated Database Updated'
+    FEDERATED_DATABASE_REMOVED = 'Federated Database Removed'
+    FEDERATED_DATABASE_QUERY_LOGS_DOWNLOADED = 'Federated Database Query Logs Downloaded'
+    INSIDE_REALM_METRIC_THRESHOLD = 'Inside Realm Metric Threshold'
+    OUTSIDE_REALM_METRIC_THRESHOLD = 'Outside Realm Metric Threshold'
+    TENANT_ENDPOINT_EXPIRED = 'Tenant Endpoint Expired'
+    DEVICE_SYNC_DEBUG_ACCESS_GRANTED = 'Device Sync Debug Access Granted'
+    DEVICE_SYNC_DEBUG_ACCESS_REVOKED = 'Device Sync Debug Access Revoked'
+    CHARGE_PROCESSING = 'Charge Processing'
+    LEGACY_2FA_RESET_EMAIL_SENT_AUDIT = 'Legacy 2Fa Reset Email Sent Audit'
+    LEGACY_2FA_RESET_AUDIT = 'Legacy 2Fa Reset Audit'
+    LEGACY_2FA_UPDATED_AUDIT = 'Legacy 2Fa Updated Audit'
+    DEVICE_SYNC_DEBUG_X509_CERT_CREATED = 'Device Sync Debug X509 Cert Created'
+    ONLINE_ARCHIVE_MAX_CONSECUTIVE_OFFLOAD_WINDOWS_CHECK = 'Online Archive Max Consecutive Offload Windows Check'
+    SERVERLESS_PROXIES_REPORTING = 'Serverless Proxies Reporting'
+    SERVERLESS_PROXIES_STOPPED_REPORTING = 'Serverless Proxies Stopped Reporting'
+    SUFFICIENT_APP_DB_FREE_SPACE = 'Sufficient App Db Free Space'
+    LOW_APP_DB_FREE_SPACE_PERCENT = 'Low App Db Free Space Percent'
+    SUFFICIENT_BLOCKSTORE_FREE_SPACE = 'Sufficient Blockstore Free Space'
+    LOW_BLOCKSTORE_FREE_SPACE_PERCENT = 'Low Blockstore Free Space Percent'
+    SUFFICIENT_S3_BLOCKSTORE_METADATA_DB_FREE_SPACE = 'Sufficient S3 Blockstore Metadata Db Free Space'
+    LOW_S3_BLOCKSTORE_METADATA_DB_FREE_SPACE_PERCENT = 'Low S3 Blockstore Metadata Db Free Space Percent'
+    SUFFICIENT_OPLOGSTORE_FREE_SPACE = 'Sufficient Oplogstore Free Space'
+    LOW_OPLOGSTORE_FREE_SPACE_PERCENT = 'Low Oplogstore Free Space Percent'
+    SUFFICIENT_S3_OPLOGSTORE_METADATA_DB_FREE_SPACE = 'Sufficient S3 Oplogstore Metadata Db Free Space'
+    LOW_S3_OPLOGSTORE_METADATA_DB_FREE_SPACE_PERCENT = 'Low S3 Oplogstore Metadata Db Free Space Percent'
+    PROJECT_LIVE_IMPORT_OVERRIDES_ADDED = 'Project Live Import Overrides Added'
+    PROJECT_LIVE_IMPORT_OVERRIDES_UPDATED = 'Project Live Import Overrides Updated'
+    PROJECT_LIVE_IMPORT_OVERRIDES_DELETED = 'Project Live Import Overrides Deleted'
+    CLUSTER_FORCE_PLANNED = 'Cluster Force Planned'
+    SUFFICIENT_FILESYSTEM_STORE_FREE_SPACE = 'Sufficient Filesystem Store Free Space'
+    LOW_FILESYSTEM_STORE_FREE_SPACE_PERCENT = 'Low Filesystem Store Free Space Percent'
+    PENDING_INDEXES_CANCELED = 'Pending Indexes Canceled'
