@@ -1,24 +1,62 @@
-# Copyright (c) 2019 Matthew G. Monteleone
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+from __future__ import division, absolute_import, print_function, unicode_literals
 
 from datetime import datetime
-from typing import Tuple, NewType, List, Optional
-
+from statistics import mean, StatisticsError
+from typing import Optional, Tuple, List, Iterable, NewType
+import logging
+import humanfriendly as hf
 from dateutil.parser import parse
 
 from atlasapi.atlas_types import OptionalFloat
-from atlasapi.lib import _GetAll, logger
+from atlasapi.lib import _GetAll, AtlasPeriods, AtlasGranularities
+
+logger: logging.Logger = logging.getLogger('Atlas.measurements')
+
+
+class StatisticalValues:
+    def __init__(self, data_list: list):
+        try:
+            self.samples: int = len(clean_list(data_list))
+            self.mean: float = float(mean(clean_list(data_list)))
+            self.min: float = float(min(clean_list(data_list)))
+            self.max: float = float(max(clean_list(data_list)))
+        except StatisticsError:
+            logger.warning('Could not compute statistical values.')
+            self.samples: int = 0
+            self.mean: float = 0
+            self.min: float = 0
+            self.max: float = 0
+
+
+class StatisticalValuesFriendly:
+    def __init__(self, data_list: list, data_type: str = None) -> None:
+        """Returns human-readable values for stats
+
+        Args:
+            data_list:
+            data_type: The datatype either bytes or number
+        """
+        try:
+            if data_type is None:
+                data_type = 'SCALAR_PER_SECOND'
+            if data_type == 'BYTES':
+                self.mean: str = hf.format_size(mean(clean_list(data_list)))
+                self.min: str = hf.format_size(min(clean_list(data_list)))
+                self.max: str = hf.format_size(max(clean_list(data_list)))
+            elif data_type == 'SCALAR':
+                self.mean: str = hf.format_number(mean(clean_list(data_list)))
+                self.min: str = hf.format_number(min(clean_list(data_list)))
+                self.max: str = hf.format_number(max(clean_list(data_list)))
+            else:
+                self.mean: str = hf.format_number(mean(clean_list(data_list)))
+                self.min: str = hf.format_number(min(clean_list(data_list)))
+                self.max: str = hf.format_number(max(clean_list(data_list)))
+
+        except StatisticsError:
+            logger.warning('Could not compute statistical values.')
+            self.mean: str = 'No Value'
+            self.min: str = 'No value'
+            self.max: str = 'No value'
 
 
 class AtlasMeasurementTypes(_GetAll):
@@ -71,7 +109,8 @@ class AtlasMeasurementTypes(_GetAll):
         mapped = 'MEMORY_MAPPED'
 
     class Network(_GetAll):
-        bytes_id = 'NETWORK_BYTES_IN'
+        bytes_id = 'NETWORK_BYTES_IN'  # initial typo, kept for backwards compatibility
+        bytes_in = 'NETWORK_BYTES_IN'
         bytes_out = 'NETWORK_BYTES_OUT'
         num_requests = 'NETWORK_NUM_REQUESTS'
 
@@ -111,7 +150,7 @@ class AtlasMeasurementTypes(_GetAll):
 
     class TicketsAvailable(_GetAll):
         reads = 'TICKETS_AVAILABLE_READS'
-        writes = 'TICKETS_AVAILABLE_WRITES'
+        writes = 'TICKETS_AVAILABLE_WRITE'
 
     class CPU(_GetAll):
         class Process(_GetAll):
@@ -146,25 +185,70 @@ class AtlasMeasurementTypes(_GetAll):
             guest = 'SYSTEM_NORMALIZED_CPU_GUEST'
             steal = 'SYSTEM_NORMALIZED_CPU_STEAL'
 
+    class Disk(_GetAll):
+        class IOPS(_GetAll):
+            read = 'DISK_PARTITION_IOPS_READ'
+            read_max = 'MAX_DISK_PARTITION_IOPS_READ'
+            write = 'DISK_PARTITION_IOPS_WRITE'
+            write_max = 'MAX_DISK_PARTITION_IOPS_WRITE'
+            total = 'DISK_PARTITION_IOPS_TOTAL'
+            total_max = 'MAX_DISK_PARTITION_IOPS_TOTAL'
 
+        class Util(_GetAll):
+            util = 'DISK_PARTITION_UTILIZATION'
+            util_max = 'MAX_DISK_PARTITION_UTILIZATION'
+
+        class Latency(_GetAll):
+            read = 'DISK_PARTITION_LATENCY_READ'
+            read_max = 'MAX_DISK_PARTITION_LATENCY_READ'
+            write = 'DISK_PARTITION_LATENCY_WRITE'
+            write_max = 'MAX_DISK_PARTITION_LATENCY_WRITE'
+
+        class Free(_GetAll):
+            space_free = 'DISK_PARTITION_SPACE_FREE'
+            space_free_max = 'MAX_DISK_PARTITION_SPACE_FREE'
+            used = 'DISK_PARTITION_SPACE_USED'
+            used_max = 'MAX_DISK_PARTITION_SPACE_USED'
+            percent_fee = 'DISK_PARTITION_SPACE_PERCENT_FREE'
+            percent_free_max = 'MAX_DISK_PARTITION_SPACE_PERCENT_FREE'
+            percent_used = 'DISK_PARTITION_SPACE_PERCENT_USED'
+            percent_used_max = 'MAX_DISK_PARTITION_SPACE_PERCENT_USED'
+
+    class Namespaces(_GetAll):
+        """Metrics regarding namespaces (databases) on each host.
+
+        As found in dbstats (https://www.mongodb.com/docs/manual/reference/command/dbStats/)
+            """
+        object_size = 'DATABASE_AVERAGE_OBJECT_SIZE' # dbStats.avgObjSize Average size of each document in bytes. This is the dataSize divided by the number of documents. The scale argument does not affect the avgObjSize value.
+        collection_count = 'DATABASE_COLLECTION_COUNT'
+        data_size = 'DATABASE_DATA_SIZE' # Total size of the uncompressed data held in the database. The dataSize decreases when you remove documents.
+        storage_size = 'DATABASE_STORAGE_SIZE' # Sum of the space allocated to all collections in the database for document storage, including free space. storageSize does not include space allocated to indexes. See indexSize for the total index size.
+        index_size = 'DATABASE_INDEX_SIZE' # Sum of the space allocated to all indexes in the database, including free index space.
+        index_count = 'DATABASE_INDEX_COUNT'
+        extent_count = 'DATABASE_EXTENT_COUNT' # ?
+        object_count = 'DATABASE_OBJECT_COUNT' # Number of objects (specifically, documents) in the database across all collections.
+        view_count = 'DATABASE_VIEW_COUNT'
+
+
+# noinspection PyBroadException
 class AtlasMeasurementValue(object):
-    def __init__(self, value_dict):
+    def __init__(self, value_dict: dict):
         """
         Class for holding a measurement value
         :type value_dict: dict
         :param value_dict: An Atlas standard Measurement value dictionary.
         """
-        timestamp = value_dict.get('timestamp', None)
-        value = value_dict.get('value', None)
+        timestamp: int = value_dict.get('timestamp', None)
+        value: float = value_dict.get('value', None)
         try:
-            self.timestamp = parse(timestamp)
+            self.timestamp: datetime = parse(timestamp)
         except (ValueError, TypeError):
             logger.warning('Could not parse "{}" as a datetime.')
             self.timestamp = None
         try:
             if value is None:
                 self.value = None
-            self.value = float(value)
+            self.value: float = float(value)
         except ValueError as e:
             self.value = None
             logger.warning('Could not parse the metric value "{}". Error was {}'.format(value, e))
@@ -172,21 +256,22 @@ class AtlasMeasurementValue(object):
             logger.info('Value is none.')
             self.value = None
 
+    # noinspection PyBroadException
     @property
-    def value_int(self):
+    def value_int(self) -> Optional[int]:
         try:
             return int(self.value)
-        except Exception:
+        except Exception as e:
             return None
 
     @property
-    def value_float(self):
+    def value_float(self) -> Optional[float]:
         try:
             return float(self.value)
         except Exception:
             return None
 
-    def as_dict(self):
+    def as_dict(self) -> dict:
         return dict(timestamp=self.timestamp.__str__(), value=self.value, value_int=self.value_int,
                     value_float=self.value_float)
 
@@ -200,28 +285,31 @@ class AtlasMeasurementValue(object):
         return self.timestamp, self.value
 
 
-ListOfAtlasMeasurementValues = NewType('ListOfAtlasMeasurementValues', List[Optional[AtlasMeasurementValue]])
-
-
 class AtlasMeasurement(object):
     """A point in time container for an Atlas measurement.
 
-            For a certain period, granularity and measurementType hoslds a list fo measurementValues.
+            For a certain period, granularity and measurementType holds a list fo measurementValues.
 
             Args:
                 name (AtlasMeasurementTypes): The name of the measurement type
+                units (Text): Descriptive text of units used.
                 period (AtlasPeriods): The period the measurement covers
                 granularity (AtlasGranularities): The granularity used for the measurement
                 measurements (List[AtlasMeasurementValue]): A list of the actual measurement values
             """
-    def __init__(self, name, period, granularity, measurements=list()):
-        self.name = name
-        self.period = period
-        self.granularity = granularity
-        self._measurements = measurements
+
+    def __init__(self, name: AtlasMeasurementTypes, period: AtlasPeriods,
+                 granularity: AtlasGranularities, units: str = None, measurements: List[AtlasMeasurementValue] = None):
+        if measurements is None:
+            measurements = list()
+        self.name: AtlasMeasurementTypes = name
+        self.units: str = units
+        self.period: AtlasPeriods = period
+        self.granularity: AtlasGranularities = granularity
+        self._measurements: List[AtlasMeasurementValue] = measurements
 
     @property
-    def measurements(self):
+    def measurements(self) -> Iterable[AtlasMeasurementValue]:
         """
         Getter for the measurements.
 
@@ -285,11 +373,28 @@ class AtlasMeasurement(object):
             dict:
         """
         return dict(measurements=self._measurements, date_start=self.date_start, date_end=self.date_end, name=self.name,
-                    period=self.period, granularity=self.granularity, measurements_count=self.measurements_count
+                    units=self.units, period=self.period, granularity=self.granularity,
+                    measurements_count=self.measurements_count
                     )
 
+    @property
+    def measurement_stats(self) -> StatisticalValues:
+        """Returns a statistical info for measurement data"""
+        data_list = list()
+        for each_measurement in self.measurements:
+            data_list.append(each_measurement.value_float)
+        return StatisticalValues(data_list=data_list)
+
+    @property
+    def measurement_stats_friendly(self) -> StatisticalValuesFriendly:
+        """Returns  statistical info for measurement data in friendly bytes format"""
+        data_list = list()
+        for each_measurement in self.measurements:
+            data_list.append(each_measurement.value_float)
+        return StatisticalValuesFriendly(data_list=data_list, data_type=self.units)
+
     def __hash__(self):
-        return hash(self.name+'-'+self.period)
+        return hash(self.name + '-' + self.period)
 
     def __eq__(self, other):
         """
@@ -298,6 +403,20 @@ class AtlasMeasurement(object):
         :return:
         """
         if isinstance(other, AtlasMeasurement):
-            return  ((self.name == other.name) and (self.period == other.period))
+            return (self.name == other.name) and (self.period == other.period)
 
-OptionalAtlasMeasurement = NewType('OptionalAtlasMeasurement', Optional[AtlasMeasurement])
\ No newline at end of file
+
+ListOfAtlasMeasurementValues = NewType('ListOfAtlasMeasurementValues', List[Optional[AtlasMeasurementValue]])
+OptionalAtlasMeasurement = NewType('OptionalAtlasMeasurement', Optional[AtlasMeasurement])
+
+
+def clean_list(data_list: list) -> list:
+    """Returns a list with any none values removed
+
+    Args:
+        data_list (list): The list to be cleaned
+
+    Returns (list): The list cleaned of None values.
+
+    """
+    return list(filter(None, data_list))
